//
//  ContentMainRecommendSeriesViewModel.swift
//  SodaLive
//
//  Created by klaus on 5/7/24.
//

import Foundation
import Combine

final class ContentMainRecommendSeriesViewModel: ObservableObject {
    
    private let repository = SeriesRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var seriesList = [SeriesListItem]()
    
    func getRecommendSeriesList() {
        repository.getRecommendSeriesList()
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponse<[SeriesListItem]>.self, from: responseData)
                    self.isLoading = false
                    
                    if let data = decoded.data, decoded.success {
                        self.seriesList.removeAll()
                        self.seriesList.append(contentsOf: data)
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                        } else {
                            self.errorMessage = "추천 시리즈를 불러오지 못했습니다. 다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "추천 시리즈를 불러오지 못했습니다. 다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                    self.isShowPopup = true
                    self.isLoading = false
                }
            }
            .store(in: &subscription)
    }
}
