//
//  ContentMainAlarmAllViewModel.swift
//  SodaLive
//
//  Created by klaus on 2/22/25.
//

import Foundation
import Combine

final class ContentMainAlarmAllViewModel: ObservableObject {
    
    private let repository = ContentMainTabAlarmRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var themeList = ["전체", "모닝콜", "슬립콜", "알람"]
    @Published var newContentList = [GetAudioContentMainItem]()
    
    @Published var selectedTheme = "전체" {
        didSet {
            page = 1
            isLast = false
            getContentMainAlarmAll()
        }
    }
    @Published var totalCount = 0
    
    var page = 1
    var isLast = false
    private let pageSize = 20
    
    func getContentMainAlarmAll() {
        if (!isLast && !isLoading) {
            isLoading = true
            
            repository.getContentMainAlarmAll(
                theme: selectedTheme == "전체" ? "" : selectedTheme,
                page: page,
                size: pageSize
            )
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    self.isLoading = false
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetNewContentAllResponse>.self, from: responseData)
                        self.isLoading = false
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                newContentList.removeAll()
                            }
                            
                            self.totalCount = data.totalCount
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.newContentList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                        self.isLoading = false
                    }
                }
                .store(in: &subscription)
        } else {
            isLoading = false
        }
    }
}
