//
//  SeriesListAllViewModel.swift
//  SodaLive
//
//  Created by klaus on 4/29/24.
//

import Foundation
import Combine

final class SeriesListAllViewModel: ObservableObject {
    private let repository = SeriesRepository()
    private var subscription = Set<AnyCancellable>()
    
    enum SeriesSortType: String {
        case NEWEST, OLDEST
    }
    
    var creatorId: Int = 0
    
    @Published var isLoading = false
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var seriesList = [SeriesListItem]()
    
    var page = 1
    var isLast = false
    private let pageSize = 10
    
    func getSeriesList() {
        if !isLoading && !isLast {
            isLoading = true
            repository
                .getSeriesList(creatorId: creatorId, sortType: .NEWEST, page: page, size: pageSize)
                .sink { result in
                    switch result {
                    case .finished:
                        DEBUG_LOG("finish")
                    case .failure(let error):
                        ERROR_LOG(error.localizedDescription)
                    }
                } receiveValue: { [unowned self] response in
                    let responseData = response.data
                    
                    do {
                        let jsonDecoder = JSONDecoder()
                        let decoded = try jsonDecoder.decode(ApiResponse<GetSeriesListResponse>.self, from: responseData)
                        
                        if let data = decoded.data, decoded.success {
                            if page == 1 {
                                self.seriesList.removeAll()
                            }
                            
                            if !data.items.isEmpty {
                                page += 1
                                self.seriesList.append(contentsOf: data.items)
                            } else {
                                isLast = true
                            }
                        } else {
                            if let message = decoded.message {
                                self.errorMessage = message
                            } else {
                                self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                            }
                            
                            self.isShowPopup = true
                        }
                    } catch {
                        self.errorMessage = "다시 시도해 주세요.\n계속 같은 문제가 발생할 경우 고객센터로 문의 주시기 바랍니다."
                        self.isShowPopup = true
                    }
                    
                    self.isLoading = false
                }
                .store(in: &subscription)
        }
    }
    
}
