//
//  TextMessageDetailViewModel.swift
//  SodaLive
//
//  Created by klaus on 2023/08/10.
//

import Foundation
import Combine

final class TextMessageDetailViewModel: ObservableObject {
    
    private let repository = MessageRepository()
    private var subscription = Set<AnyCancellable>()
    
    @Published var errorMessage = ""
    @Published var isShowPopup = false
    @Published var isLoading = false
    
    @Published var saveMessagePrice = 0
    @Published var isShowSavePopup = false
    
    var messageId = 0
    
    func deleteMessage(onSuccess: @escaping () -> Void) {
        if messageId <= 0 {
            errorMessage = "메시지를 삭제하지 못했습니다\n잠시 후 다시 시도해 주세요."
            isShowPopup = true
            return
        }
        
        isLoading = true
        
        repository.deleteMessage(messageId: messageId)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        self.errorMessage = "삭제되었습니다."
                        self.isShowPopup = true
                        DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
                            onSuccess()
                        }
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                            self.isShowPopup = true
                        } else {
                            self.errorMessage = "메시지를 보관하지 못했습니다.\n잠시 후 다시 시도해 주세요."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "메시지를 보관하지 못했습니다.\n잠시 후 다시 시도해 주세요."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
    
    func keepTextMessage() {
        if messageId <= 0 {
            errorMessage = "메시지를 저장하지 못했습니다\n잠시 후 다시 시도해 주세요."
            isShowPopup = true
            return
        }
        
        isLoading = true
        repository.keepTextMessage(messageId: messageId)
            .sink { result in
                switch result {
                case .finished:
                    DEBUG_LOG("finish")
                case .failure(let error):
                    ERROR_LOG(error.localizedDescription)
                }
            } receiveValue: { [unowned self] response in
                self.isLoading = false
                let responseData = response.data
                
                do {
                    let jsonDecoder = JSONDecoder()
                    let decoded = try jsonDecoder.decode(ApiResponseWithoutData.self, from: responseData)
                    
                    if decoded.success {
                        self.errorMessage = "보관되었습니다."
                        self.isShowPopup = true
                    } else {
                        if let message = decoded.message {
                            self.errorMessage = message
                            self.isShowPopup = true
                        } else {
                            self.errorMessage = "메시지를 보관하지 못했습니다.\n잠시 후 다시 시도해 주세요."
                        }
                        
                        self.isShowPopup = true
                    }
                } catch {
                    self.errorMessage = "메시지를 보관하지 못했습니다.\n잠시 후 다시 시도해 주세요."
                    self.isShowPopup = true
                }
            }
            .store(in: &subscription)
    }
}
